import { BaseContract } from "@zapjs/basecontract";
import { TransferType, address, txid, NetworkProviderOptions, BNType } from "@zapjs/types";
/**
* @class
* Provides Represents an interface to the Zap Token ERC20 contract. Enables token transfers, balance lookups, and approvals.
*/
export declare class ZapToken extends BaseContract {
    /**
     * @constructor
     * @param {NetworkProviderOptions} n. {artifactDir,networkId,networkProvider}
     * @param {string} n.artifactsDir - Directory where contract ABIs are located
     * @param {number|string} n.networkId - Select which network the contract is located on (mainnet, testnet, private)
     * @param {any} n.networkProvider - Ethereum network provider (e.g. Infura)
     * @example new ZapToken({networkId : 42, networkProvider : web3})
     */
    constructor(obj?: NetworkProviderOptions);
    /**
     * Get the Zap Token balance of a given address.
     * @param {address} address  Address to check
     * @returns {Promise<number>} Returns a Promise that will eventually resolve into a Zap balance (wei)
     */
    balanceOf(address: address): Promise<string | BNType>;
    /**
     * Transfers Zap from an address to another address.
     * @param {TransferType} t. {to, amount, from,gas=Util.DEFAULT_GAS}
     * @param {address} t.to - Address of the recipient
     * @param {number} t.amount - Amount of Zap to transfer (wei)
     * @param {address} t.from - Address of the sender
     * @param {number} t.gas - Sets the gas limit for this transaction (optional)
     * @returns {Promise<txid>} Returns a Promise that will eventually resolve into a transaction hash
     */
    send({ to, amount, from, gasPrice, gas }: TransferType): Promise<txid>;
    /**
     * Allocates Zap Token from the Zap contract owner to an address (ownerOnly).
     * @param {TransferType} t. {to, amount, from,gas=Util.DEFAULT_GAS}
     * @param {address} t.to - Address of the recipient
     * @param {number} t.amount - Amount of Zap to allocate (wei)
     * @param {address} t.from - Address of the sender (must be owner of the Zap contract)
     * @param {number} t.gas - Sets the gas limit for this transaction (optional)
     * @returns {Promise<txid>} Returns a Promise that will eventually resolve into a transaction hash
     */
    allocate({ to, amount, from, gasPrice, gas }: TransferType): Promise<txid>;
    /**
     * Approves the transfer of Zap Token from a holder to another account. Enables the bondage contract to transfer Zap during the bondage process.
     * @param {TransferType} t. {to, amount, from, gas=Util.DEFAULT_GAS}
     * @param {address} t.to - Address of the recipient
     * @param {number} t.amount - Amount of Zap to approve (wei)
     * @param {address} t.from - Address of the sender
     * @param {number} t.gas - Sets the gas limit for this transaction (optional)
     * @returns {Promise<txid>} Returns a Promise that will eventually resolve into a transaction hash
     */
    approve({ to, amount, from, gasPrice, gas }: TransferType): Promise<txid>;
}
